@@ -559,7 +559,6 @@ bool Collection::removeEntries(const Tellico::Data::EntryList& vec_) {
     return false;
   }
 
-//  myDebug() << "deleted entry - " << entry_->title();
   removeEntriesFromDicts(vec_, fieldNames());
   bool success = true;
   foreach(EntryPtr entry, vec_) {
@@ -801,7 +800,28 @@ void Collection::addBorrower(Tellico::Data::BorrowerPtr borrower_) {
   if(!borrower_) {
     return;
   }
-  m_borrowers.append(borrower_);
+  // check against existing borrower uid
+  BorrowerPtr existingBorrower;
+  foreach(BorrowerPtr bor, m_borrowers) {
+    if(bor->uid() == borrower_->uid()) {
+      existingBorrower = bor;
+      break;
+    }
+  }
+  if(!existingBorrower) {
+    m_borrowers.append(borrower_);
+  } else if(existingBorrower != borrower_) {
+    // need to merge loans
+    QHash<QString, LoanPtr> existingLoans;
+    foreach(LoanPtr loan, existingBorrower->loans()) {
+      existingLoans.insert(loan->uid(), loan);
+    }
+    foreach(LoanPtr loan, borrower_->loans()) {
+      if(!existingLoans.contains(loan->uid())) {
+        existingBorrower->addLoan(loan);
+      }
+    }
+  }
 }
 
 void Collection::addFilter(Tellico::FilterPtr filter_) {
