@@ -49,6 +49,7 @@ namespace Tellico {
   }
   namespace GUI {
     class ComboBox;
+    class CollectionTypeCombo;
   }
 
 /**
@@ -119,6 +120,7 @@ private slots:
   void slotSelectedSourceChanged(QListWidgetItem* item);
   void slotMoveUpSourceClicked();
   void slotMoveDownSourceClicked();
+  void slotSourceFilterChanged();
   void slotNewStuffClicked();
   void slotShowTemplatePreview();
   void slotInstallTemplate();
@@ -206,14 +208,17 @@ private:
   KPushButton* m_moveDownSourceBtn;
   KPushButton* m_removeSourceBtn;
   KPushButton* m_newStuffBtn;
+  QCheckBox* m_cbFilterSource;
+  GUI::CollectionTypeCombo* m_sourceTypeCombo;
 };
 
 class GeneralFetcherInfo {
 public:
-  GeneralFetcherInfo(Fetch::Type t, const QString& n, bool o) : type(t), name(n), updateOverwrite(o) {}
+  GeneralFetcherInfo(Fetch::Type t, const QString& n, bool o, QString u=QString()) : type(t), name(n), updateOverwrite(o), uuid(u) {}
   Fetch::Type type;
   QString name;
   bool updateOverwrite;
+  QString uuid;
 };
 
 class SourceListItem : public QListWidgetItem {
@@ -223,13 +228,14 @@ public:
   SourceListItem(KListWidget* parent, const GeneralFetcherInfo& info,
                  const QString& groupName = QString());
 
-  void setConfigGroup(const QString& s) { m_configGroup = s; }
+  void setConfigGroup(const QString& s) { m_configGroup = s; if(m_fetcher) m_fetcher->setConfigGroup(s); }
   const QString& configGroup() const { return m_configGroup; }
   const Fetch::Type& fetchType() const { return m_info.type; }
   void setUpdateOverwrite(bool b) { m_info.updateOverwrite = b; }
   bool updateOverwrite() const { return m_info.updateOverwrite; }
   void setNewSource(bool b) { m_newSource = b; }
   bool isNewSource() const { return m_newSource; }
+  QString uuid() const { return m_info.uuid; }
   void setFetcher(Fetch::Fetcher::Ptr fetcher);
   Fetch::Fetcher::Ptr fetcher() const { return m_fetcher; }
 
