@@ -33,6 +33,7 @@
 #include "fieldformat.h"
 #include "tellico_strings.h"
 #include "images/imagefactory.h"
+#include "images/imagedirectory.h"
 #include "images/image.h"
 #include "images/imageinfo.h"
 #include "utils/stringset.h"
@@ -267,23 +268,29 @@ void Document::deleteContents() {
 }
 
 void Document::appendCollection(Tellico::Data::CollPtr coll_) {
-  if(!coll_) {
+  appendCollection(m_coll, coll_);
+}
+
+void Document::appendCollection(Tellico::Data::CollPtr coll1_, Tellico::Data::CollPtr coll2_) {
+  if(!coll1_ || !coll2_) {
     return;
   }
 
-  m_coll->blockSignals(true);
+  coll1_->blockSignals(true);
 
-  foreach(FieldPtr field, coll_->fields()) {
-    m_coll->mergeField(field);
+  foreach(FieldPtr field, coll2_->fields()) {
+    coll1_->mergeField(field);
   }
 
-  foreach(EntryPtr entry, coll_->entries()) {
+  Data::EntryList newEntries;
+  foreach(EntryPtr entry, coll2_->entries()) {
     Data::EntryPtr newEntry(new Data::Entry(*entry));
-    newEntry->setCollection(m_coll);
+    newEntry->setCollection(coll1_);
+    newEntries << newEntry;
   }
-  m_coll->addEntries(coll_->entries());
+  coll1_->addEntries(newEntries);
   // TODO: merge filters and loans
-  m_coll->blockSignals(false);
+  coll1_->blockSignals(false);
 }
 
 Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll_) {
@@ -496,7 +503,7 @@ void Document::slotLoadAllImages() {
       }
       // this is the early loading, so just by calling imageById()
       // the image gets sucked from the zip file and written to disk
-      //by ImageFactory::imageById()
+      // by ImageFactory::imageById()
       if(ImageFactory::imageById(id).isNull()) {
         myDebug() << "entry title:" << entry->title();
       }
@@ -519,17 +526,22 @@ void Document::slotLoadAllImages() {
   }
 
   m_cancelImageWriting = false;
+  m_importer->deleteLater();
+  m_importer = 0;
 }
 
+// cacheDir_ is the location dir to write the images
+// localDir_ provide the new file location which is only needed if cacheDir == LocalDir
 void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
   // images get 80 steps in saveDocument()
   const uint stepSize = 1 + qMax(1, m_coll->entryCount()/80); // add 1 since it could round off
   uint j = 1;
 
-  QString oldLocalDir = ImageFactory::localDir();
-  ImageFactory::setLocalDirectory(localDir_);
-
   ImageFactory::CacheDir cacheDir = static_cast<ImageFactory::CacheDir>(cacheDir_);
+  ImageDirectory* imgDir = 0;
+  if(cacheDir == ImageFactory::LocalDir) {
+    imgDir = new ImageDirectory(ImageFactory::localDirectory(localDir_));
+  }
 
   QString id;
   StringSet images;
@@ -545,7 +557,14 @@ void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
       if(ImageFactory::imageInfo(id).linkOnly) {
         continue;
       }
-      if(!ImageFactory::writeCachedImage(id, cacheDir)) {
+      // careful here, if we're writing to LocalDir, need to read from the old LocalDir and write to new
+      bool success;
+      if(cacheDir == ImageFactory::LocalDir) {
+        success = ImageFactory::writeCachedImage(id, imgDir);
+      } else {
+        success = ImageFactory::writeCachedImage(id, cacheDir);
+      }
+      if(!success) {
         myDebug() << "did not write image for entry title:" << entry->title();
       }
       if(m_cancelImageWriting) {
@@ -567,7 +586,6 @@ void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
   }
 
   m_cancelImageWriting = false;
-  ImageFactory::setLocalDirectory(oldLocalDir);
 }
 
 bool Document::pruneImages() {
@@ -753,4 +771,47 @@ bool Document::mergeEntry(Data::EntryPtr e1, Data::EntryPtr e2, MergeConflictRes
   return ret;
 }
 
+//static
+QPair<Tellico::Data::FieldList, Tellico::Data::FieldList> Document::mergeFields(Data::CollPtr coll_,
+                                                                                Data::FieldList fields_,
+                                                                                Data::EntryList entries_) {
+  Data::FieldList modified, created;
+  foreach(Data::FieldPtr field, fields_) {
+    // don't add a field if it's a default field and not in the current collection
+    if(coll_->hasField(field->name()) || CollectionFactory::isDefaultField(coll_->type(), field->name())) {
+      // special case for choice fields, since we might want to add a value
+      if(field->type() == Data::Field::Choice && coll_->hasField(field->name())) {
+        // a2 are the existing fields in the collection, keep them in the same order
+        QStringList a1 = coll_->fieldByName(field->name())->allowed();
+        foreach(const QString& newAllowedValue, field->allowed()) {
+          if(!a1.contains(newAllowedValue)) {
+            // could be slow for large merges, but we do only want to add new value
+            // IF that value is actually used by an entry
+            foreach(Data::EntryPtr entry, entries_) {
+              if(entry->field(field->name()) == newAllowedValue) {
+                a1 += newAllowedValue;
+                break;
+              }
+            }
+          }
+        }
+        if(a1.count() != coll_->fieldByName(field->name())->allowed().count()) {
+          Data::FieldPtr f(new Data::Field(*coll_->fieldByName(field->name())));
+          f->setAllowed(a1);
+          modified.append(f);
+        }
+      }
+      continue;
+    }
+    // add field if any values are not empty
+    foreach(Data::EntryPtr entry, entries_) {
+      if(!entry->field(field).isEmpty()) {
+        created.append(Data::FieldPtr(new Data::Field(*field)));
+        break;
+      }
+    }
+  }
+  return qMakePair(modified, created);
+}
+
 #include "document.moc"
