@@ -142,10 +142,11 @@ public:
    * @param coll A pointer to the appended collection.
    */
   void appendCollection(CollPtr coll);
+  static void appendCollection(CollPtr targetColl, CollPtr sourceColl);
   /**
    * Merges another collection into this one. The collections must be the same type. Fields in the
    * current collection are left alone. Fields not in the current are added. The merging is slow
-   * since each entry in @p coll must be compared to ever entry in the current collection.
+   * since each entry in @p coll must be compared to every entry in the current collection.
    *
    * @param coll A pointer to the collection to be merged.
    * @return A QPair of the merged entries, see note in datavectors.h
@@ -178,6 +179,11 @@ public:
   void cancelImageWriting() { m_cancelImageWriting = true; }
 
   static bool mergeEntry(EntryPtr entry1, EntryPtr entry2, MergeConflictResolver* resolver=0);
+  // adds new fields into collection if any values in entries are not empty
+  // first object is modified fields, second is new fields
+  static QPair<Data::FieldList, Data::FieldList> mergeFields(Data::CollPtr coll,
+                                                             Data::FieldList fields,
+                                                             Data::EntryList entries);
 
 public slots:
   /**
