@@ -171,12 +171,10 @@ void EntryEditDialog::setLayout(Tellico::Data::CollPtr coll_) {
 
     // if this layout model is changed, be sure to check slotUpdateField()
     QWidget* page = new QWidget(m_tabs);
-    // (parent, margin, spacing)
     QBoxLayout* boxLayout = new QVBoxLayout(page);
 
     QWidget* grid = new QWidget(page);
     gridList.append(grid);
-    // (parent, nrows, ncols, margin, spacing)
     // spacing gets a bit weird, if there are absolutely no Choice fields,
     // then spacing should be 5, which is set later
     QGridLayout* layout = new QGridLayout(grid);
@@ -564,7 +562,6 @@ void EntryEditDialog::removeField(Tellico::Data::CollPtr, Tellico::Data::FieldPt
       QVector<int> maxWidth(NCOLS, 0);
 
       Data::FieldList vec = m_currColl->fieldsByCategory(field_->category());
-      Data::FieldList::Iterator it = vec.begin();
       int count = 0;
       foreach(Data::FieldPtr field, vec) {
         GUI::FieldWidget* widget = m_widgetDict.value(QString::number(m_currColl->id()) + field->name());
