@@ -80,7 +80,21 @@ enum Type {
   Douban,
   BiblioShare,
   MovieMeter,
-  GoogleBook
+  GoogleBook,
+  MAS,
+  Springer,
+  Allocine,
+  ScreenRush,
+  FilmStarts,
+  SensaCine,
+  Beyazperde,
+  HathiTrust,
+  TheGamesDB,
+  DBLP,
+  VNDB,
+  MRLookup,
+  BoardGameGeek,
+  Bedetheque
 };
 
   }
