@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2009 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2009-2011 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -49,12 +49,27 @@
 #include "giantbombfetcher.h"
 #include "openlibraryfetcher.h"
 #include "multifetcher.h"
-#ifdef HAVE_QJSON
 #include "freebasefetcher.h"
 #include "filmasterfetcher.h"
-#endif
+#include "masfetcher.h"
+#include "hathitrustfetcher.h"
+#include "vndbfetcher.h"
 #include "dvdfrfetcher.h"
 #include "doubanfetcher.h"
+#include "bibliosharefetcher.h"
+#include "moviemeterfetcher.h"
+#include "googlebookfetcher.h"
+#include "springerfetcher.h"
+#include "allocinefetcher.h"
+#include "screenrushfetcher.h"
+#include "filmstartsfetcher.h"
+#include "sensacinefetcher.h"
+#include "beyazperdefetcher.h"
+#include "thegamesdbfetcher.h"
+#include "dblpfetcher.h"
+#include "mrlookupfetcher.h"
+#include "boardgamegeekfetcher.h"
+#include "bedethequefetcher.h"
 
 /**
  * Ideally, I'd like these initializations to be in each cpp file for each collection type
@@ -83,17 +98,35 @@ Tellico::Fetch::FetcherInitializer::FetcherInitializer() {
   RegisterFetcher<Fetch::CitebaseFetcher> registerCitebase(Citebase);
   RegisterFetcher<Fetch::BibsonomyFetcher> registerBibsonomy(Bibsonomy);
   RegisterFetcher<Fetch::GoogleScholarFetcher> registerGoogle(GoogleScholar);
-  RegisterFetcher<Fetch::DiscogsFetcher> registerDiscogs(Discogs);
   RegisterFetcher<Fetch::WineComFetcher> registerWine(WineCom);
-  RegisterFetcher<Fetch::TheMovieDBFetcher> registerTMDB(TheMovieDB);
   RegisterFetcher<Fetch::MusicBrainzFetcher> registerMB(MusicBrainz);
   RegisterFetcher<Fetch::GiantBombFetcher> registerBomb(GiantBomb);
   RegisterFetcher<Fetch::OpenLibraryFetcher> registerOpenLibrary(OpenLibrary);
   RegisterFetcher<Fetch::MultiFetcher> registerMulti(Multiple);
 #ifdef HAVE_QJSON
+  RegisterFetcher<Fetch::DiscogsFetcher> registerDiscogs(Discogs);
+  RegisterFetcher<Fetch::TheMovieDBFetcher> registerTMDB(TheMovieDB);
   RegisterFetcher<Fetch::FreebaseFetcher> registerFreebase(Freebase);
   RegisterFetcher<Fetch::FilmasterFetcher> registerFilmaster(Filmaster);
+  RegisterFetcher<Fetch::GoogleBookFetcher> registerGoogleBook(GoogleBook);
+  RegisterFetcher<Fetch::MASFetcher> registerMAS(MAS);
+  RegisterFetcher<Fetch::HathiTrustFetcher> registerHathiTrust(HathiTrust);
+  RegisterFetcher<Fetch::VNDBFetcher> registerVNDB(VNDB);
+  RegisterFetcher<Fetch::AllocineFetcher> registerAllocine(Allocine);
+  RegisterFetcher<Fetch::MovieMeterFetcher> registerMovieMeter(MovieMeter);
+  // add these back if the API gets updated
+//  RegisterFetcher<Fetch::ScreenRushFetcher> registerScreenRush(ScreenRush);
+//  RegisterFetcher<Fetch::FilmStartsFetcher> registerFilmStarts(FilmStarts);
+//  RegisterFetcher<Fetch::SensaCineFetcher> registerSensaCine(SensaCine);
+//  RegisterFetcher<Fetch::BeyazperdeFetcher> registerBeyazperde(Beyazperde);
 #endif
   RegisterFetcher<Fetch::DVDFrFetcher> registerDVDFr(DVDFr);
   RegisterFetcher<Fetch::DoubanFetcher> registerDouban(Douban);
+  RegisterFetcher<Fetch::BiblioShareFetcher> registerBiblioShare(BiblioShare);
+  RegisterFetcher<Fetch::SpringerFetcher> registerSpringer(Springer);
+  RegisterFetcher<Fetch::TheGamesDBFetcher> registerTheGamesDB(TheGamesDB);
+  RegisterFetcher<Fetch::DBLPFetcher> registerDBLP(DBLP);
+  RegisterFetcher<Fetch::MRLookupFetcher> registerMRLookup(MRLookup);
+  RegisterFetcher<Fetch::BoardGameGeekFetcher> registerBGG(BoardGameGeek);
+  RegisterFetcher<Fetch::BedethequeFetcher> registerBD(Bedetheque);
 }
