@@ -159,6 +159,9 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
     stop();
     return;
   }
+  // see bug 319662. If fetcher is cancelled, job is killed
+  // if the pointer is retained, it gets double-deleted
+  m_job = 0;
 
   if(m_total == -1) {
     QDomDocument dom;
@@ -180,7 +183,7 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
   QFile f(QLatin1String("/tmp/test.xml"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec(QTextCodec::codecForName("UTF-8"));
+    t.setCodec("UTF-8");
     t << data;
   }
   f.close();
@@ -197,6 +200,8 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
   // assume always utf-8
   QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data, data.size()));
   Import::TellicoImporter imp(str);
+  // be quiet when loading images
+  imp.setOptions(imp.options() ^ Import::ImportShowImageErrors);
   Data::CollPtr coll = imp.collection();
   if(!coll) {
     myDebug() << "no collection pointer";
@@ -251,19 +256,19 @@ Tellico::Data::EntryPtr MusicBrainzFetcher::fetchEntryHook(uint uid_) {
   QFile f(QLatin1String("/tmp/test2.xml"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec(QTextCodec::codecForName("UTF-8"));
+    t.setCodec("UTF-8");
     t << output;
   }
   f.close();
 #endif
 
   Import::TellicoImporter imp(m_xsltHandler->applyStylesheet(output));
-  // hide image errors
-  imp.setOptions(imp.options() & ~Import::ImportShowImageErrors);
+  // be quiet when loading images
+  imp.setOptions(imp.options() ^ Import::ImportShowImageErrors);
   Data::CollPtr coll = imp.collection();
 //  getTracks(entry);
-  if(!coll) {
-    myWarning() << "no collection pointer";
+  if(!coll || coll->entries().isEmpty()) {
+    myWarning() << "no collection pointer or no entries";
     return entry;
   }
 
