@@ -65,8 +65,8 @@ SRUFetcher::SRUFetcher(QObject* parent_)
 }
 
 SRUFetcher::SRUFetcher(const QString& name_, const QString& host_, uint port_, const QString& path_,
-                       QObject* parent_) : Fetcher(parent_),
-      m_host(host_), m_port(port_), m_path(path_), m_format(QLatin1String("mods")),
+                       const QString& format_, QObject* parent_) : Fetcher(parent_),
+      m_host(host_), m_port(port_), m_path(path_), m_format(format_),
       m_job(0), m_MARCXMLHandler(0), m_MODSHandler(0), m_SRWHandler(0), m_started(false) {
   m_name = name_; // m_name is protected in super class
 }
@@ -118,7 +118,18 @@ void SRUFetcher::search() {
   u.setProtocol(QLatin1String("http"));
   u.setHost(m_host);
   u.setPort(m_port);
-  u.setPath(m_path);
+//  u.setPath(m_path);
+
+/*
+  QString uStr = QLatin1String("http://") + m_host;
+  if(m_port > 0) {
+    uStr += QLatin1Char(':') + QString::number(m_port);
+  }
+  uStr += QLatin1Char('/') + m_path;
+  u = QUrl::fromUserInput(uStr);
+*/
+  // hack to allow (for now) including extra query terms in the path, avoids double encoding
+  u.setUrl(u.url() + QLatin1Char('/') + m_path);
 
   u.addQueryItem(QLatin1String("operation"), QLatin1String("searchRetrieve"));
   u.addQueryItem(QLatin1String("version"), QLatin1String("1.1"));
@@ -208,7 +219,7 @@ void SRUFetcher::search() {
       stop();
       break;
   }
-  myDebug() << u.url();
+//  myDebug() << u.url();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   m_job->ui()->setWindow(GUI::Proxy::widget());
@@ -241,6 +252,9 @@ void SRUFetcher::slotComplete(KJob*) {
     stop();
     return;
   }
+  // see bug 319662. If fetcher is cancelled, job is killed
+  // if the pointer is retained, it gets double-deleted
+  m_job = 0;
 
 #if 0
   myWarning() << "Remove debug from srufetcher.cpp";
@@ -253,9 +267,6 @@ void SRUFetcher::slotComplete(KJob*) {
   f.close();
 #endif
 
-  // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
-
   Data::CollPtr coll;
   QString msg;
 
@@ -290,7 +301,9 @@ void SRUFetcher::slotComplete(KJob*) {
   QString modsResult;
   if(m_format == QLatin1String("mods")) {
     modsResult = result;
-  } else if(m_format == QLatin1String("marcxml") && initMARCXMLHandler()) {
+//  } else if(m_format == QLatin1String("marcxml") && initMARCXMLHandler()) {
+// some SRU data sources call it MARC21-xml or something other than marcxml
+  } else if(m_format.startsWith(QLatin1String("marc"), Qt::CaseInsensitive) && initMARCXMLHandler()) {
     modsResult = m_MARCXMLHandler->applyStylesheet(result);
   }
   if(!modsResult.isEmpty() && initMODSHandler()) {
@@ -329,8 +342,20 @@ void SRUFetcher::slotComplete(KJob*) {
     return;
   }
 
-  Data::EntryList entries = coll->entries();
-  foreach(Data::EntryPtr entry, entries) {
+  // since the Dewey and LoC field titles have a context in their i18n call here
+  // but not in the stylesheet where the field is actually created
+  // update the field titles here
+  QHashIterator<QString, QString> i(allOptionalFields());
+  while(i.hasNext()) {
+    i.next();
+    Data::FieldPtr field = coll->fieldByName(i.key());
+    if(field) {
+      field->setTitle(i.value());
+      coll->modifyField(field);
+    }
+  }
+
+  foreach(Data::EntryPtr entry, coll->entries()) {
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
     m_entries.insert(r->uid, entry);
     emit signalResultFound(r);
@@ -436,7 +461,7 @@ bool SRUFetcher::initSRWHandler() {
 
 Tellico::Fetch::Fetcher::Ptr SRUFetcher::libraryOfCongress(QObject* parent_) {
   return Fetcher::Ptr(new SRUFetcher(i18n("Library of Congress (US)"), QLatin1String("z3950.loc.gov"), 7090,
-                                     QLatin1String("voyager"), parent_));
+                                     QLatin1String("voyager"), QLatin1String("mods"), parent_));
 }
 
 QString SRUFetcher::defaultName() {
@@ -452,6 +477,8 @@ Tellico::StringHash SRUFetcher::allOptionalFields() {
   StringHash hash;
   hash[QLatin1String("address")]  = i18n("Address");
   hash[QLatin1String("abstract")] = i18n("Abstract");
+  hash[QLatin1String("dewey")]    = i18nc("Dewey Decimal classification system", "Dewey Decimal");
+  hash[QLatin1String("lcc")]      = i18nc("Library of Congress classification system", "LoC Classification");
   return hash;
 }
 
@@ -505,8 +532,9 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
   m_formatCombo->addItem(QLatin1String("MARCXML"), QLatin1String("marcxml"));
   m_formatCombo->addItem(QLatin1String("PAM"), QLatin1String("pam"));
   m_formatCombo->addItem(QLatin1String("Dublin Core"), QLatin1String("dc"));
-  m_formatCombo->addItem(QLatin1String(""), QLatin1String("none"));
+  m_formatCombo->setEditable(true);
   connect(m_formatCombo, SIGNAL(activated(int)), SLOT(slotSetModified()));
+  connect(m_formatCombo, SIGNAL(editTextChanged(QString)), SLOT(slotSetModified()));
   l->addWidget(m_formatCombo, row, 1);
   w = i18n("Enter the result format used by the server.");
   label->setWhatsThis(w);
@@ -522,6 +550,9 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
     m_hostEdit->setText(fetcher_->m_host);
     m_portSpinBox->setValue(fetcher_->m_port);
     m_pathEdit->setText(fetcher_->m_path);
+    if(m_formatCombo->findData(fetcher_->m_format) == -1) {
+      m_formatCombo->addItem(fetcher_->m_format, fetcher_->m_format);
+    }
     m_formatCombo->setCurrentData(fetcher_->m_format);
   }
   KAcceleratorManager::manage(optionsWidget());
@@ -540,7 +571,11 @@ void SRUFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
   if(!s.isEmpty()) {
     config_.writeEntry("Path", s);
   }
-  s = m_formatCombo->currentData().toString();
+  s = m_formatCombo->currentData().toString().trimmed();
+  if(s.isEmpty()) {
+    // user-entered format will not have data set for the item. Just use the text itself
+    s = m_formatCombo->currentText().trimmed();
+  }
   if(!s.isEmpty()) {
     config_.writeEntry("Format", s);
   }
