@@ -91,7 +91,7 @@ DateWidget::DateWidget(QWidget* parent_) : QWidget(parent_) {
   l->setStretchFactor(m_monthCombo, 1);
   // allow empty item
   m_monthCombo->addItem(QString());
-  QDate d;
+  QDate d = QDate::currentDate();
   for(int i = 1; ; ++i) {
     QString str = locale->calendar()->monthName(i, locale->calendar()->year(d));
     if(str.isEmpty()) {
@@ -178,11 +178,19 @@ QString DateWidget::text() const {
   s += QLatin1Char('-');
   // first item is empty
   if(m_monthCombo->currentIndex() > 0) {
+    // zero-pad to two digits
+    if(m_monthCombo->currentIndex() < 10) {
+      s += QLatin1Char('0');
+    }
     s += QString::number(m_monthCombo->currentIndex());
     empty = false;
   }
   s += QLatin1Char('-');
   if(m_daySpin->value() > m_daySpin->minimum()) {
+    // zero-pad to two digits
+    if(m_daySpin->value() < 10) {
+      s += QLatin1Char('0');
+    }
     s += QString::number(m_daySpin->value());
     empty = false;
   }
