@@ -36,6 +36,8 @@
 #include <kapplication.h>
 #include <kcolorutils.h>
 
+#include <QFileInfo>
+#include <QDir>
 #ifdef HAVE_QIMAGEBLITZ
 #include <qimageblitz.h>
 #endif
@@ -283,15 +285,7 @@ bool ImageFactory::writeCachedImage(const QString& id_, CacheDir dir_, bool forc
                           (dir_ == TempDir ? &factory->d->tempImageDir :
                                              &factory->d->localImageDir);
   Q_ASSERT(imgDir);
-  bool exists = imgDir->hasImage(id_);
-  // only write if it doesn't exist
-  bool success = (!force_ && exists);
-  if(!success) {
-    const Data::Image& img = imageById(id_);
-    if(!img.isNull()) {
-      success = imgDir->writeImage(img);
-    }
-  }
+  bool success = writeCachedImage(id_, imgDir, force_);
 
   if(success) {
     // remove from dict and add to cache
@@ -308,6 +302,24 @@ bool ImageFactory::writeCachedImage(const QString& id_, CacheDir dir_, bool forc
   return success;
 }
 
+bool ImageFactory::writeCachedImage(const QString& id_, ImageDirectory* imgDir_, bool force_ /*=false*/) {
+  if(id_.isEmpty() || !imgDir_) {
+    return false;
+  }
+// myLog() << "looking in" << imgDir_->path();
+  bool exists = imgDir_->hasImage(id_);
+  // only write if it doesn't exist
+  bool success = (!force_ && exists);
+  if(!success) {
+    const Data::Image& img = imageById(id_);
+    if(!img.isNull()) {
+//      myLog() << "writing image";
+      success = imgDir_->writeImage(img);
+    }
+  }
+  return success;
+}
+
 const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
   Q_ASSERT(factory);
   if(id_.isEmpty() || !factory) {
@@ -370,37 +382,42 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
     }
   }
 
-  CacheDir dir1 = TempDir;
-  CacheDir dir2 = TempDir;
-  ImageDirectory* imgDir1 = 0;
-  ImageDirectory* imgDir2 = 0;
+  // This section uses the config image setting plus the fallback location
+  // to provide confidence that the user's image can be found
+  CacheDir configLoc = TempDir;
+  CacheDir fallbackLoc = TempDir;
+  ImageDirectory* configImgDir = 0;
+  ImageDirectory* fallbackImgDir = 0;
   if(Config::imageLocation() == Config::ImagesInLocalDir) {
-    dir1 = LocalDir;
-    dir2 = DataDir;
-    imgDir1 = &factory->d->localImageDir;
-    imgDir2 = &factory->d->dataImageDir;
+    configLoc = LocalDir;
+    fallbackLoc = DataDir;
+    configImgDir = &factory->d->localImageDir;
+    fallbackImgDir = &factory->d->dataImageDir;
   } else if(Config::imageLocation() == Config::ImagesInAppDir) {
-    dir1 = DataDir;
-    dir2 = LocalDir;
-    imgDir1 = &factory->d->dataImageDir;
-    imgDir2 = &factory->d->localImageDir;
+    configLoc = DataDir;
+    fallbackLoc = LocalDir;
+    configImgDir = &factory->d->dataImageDir;
+    fallbackImgDir = &factory->d->localImageDir;
   }
 
-  if(imgDir1 && imgDir1->hasImage(id_)) {
-    const Data::Image& img2 = factory->addCachedImageImpl(id_, dir1);
+  // check the configured location first
+  if(configImgDir && configImgDir->hasImage(id_)) {
+    const Data::Image& img2 = factory->addCachedImageImpl(id_, configLoc);
     if(!img2.isNull()) {
+//      myLog() << "found image in configured location" << configImgDir->path();
       return img2;
     } else {
-      myDebug() << "tried to add" << id_ << "from" << imgDir1->path() << "but failed";
+      myDebug() << "tried to add" << id_ << "from" << configImgDir->path() << "but failed";
     }
-  } else if(imgDir2 && imgDir2->hasImage(id_)) {
-    const Data::Image& img2 = factory->addCachedImageImpl(id_, dir2);
+  } else if(fallbackImgDir && fallbackImgDir->hasImage(id_)) {
+    const Data::Image& img2 = factory->addCachedImageImpl(id_, fallbackLoc);
     if(!img2.isNull()) {
+//      myLog() << "found image in fallback location" << fallbackImgDir->path();
       // the img is in the other location
       factory->emitImageMismatch();
       return img2;
     } else {
-      myDebug() << "tried to add" << id_ << "from" << imgDir2->path() << "but failed";
+      myDebug() << "tried to add" << id_ << "from" << fallbackImgDir->path() << "but failed";
     }
   }
   // at this point, there's a possibility that the user has changed settings so that the images
@@ -408,15 +425,39 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
   if(factory->d->dataImageDir.hasImage(id_)) {
     const Data::Image& img2 = factory->addCachedImageImpl(id_, DataDir);
     if(!img2.isNull()) {
+//      myLog() << "found image in data dir location";
       return img2;
     }
   }
   if(factory->d->localImageDir.hasImage(id_)) {
     const Data::Image& img2 = factory->addCachedImageImpl(id_, LocalDir);
     if(!img2.isNull()) {
+//      myLog() << "found image in local dir location";
       return img2;
     }
   }
+  // now, it appears the image doesn't exist. The only remaining possibility
+  // is that the file name has multiple periods and as a result of the fix for bug 348088,
+  // the image is lurking in a local image directory without the multiple periods
+  if(Config::imageLocation() == Config::ImagesInLocalDir && QDir(localDir()).dirName().contains(QLatin1Char('.'))) {
+    QString realImageDir = localDir();
+    QDir d(realImageDir);
+    // try to cd up and into the other old directory
+    QString cdString = QLatin1String("../") + d.dirName().section(QLatin1Char('.'), 0, 0) + QLatin1String("_files/");
+    if(d.cd(cdString)) {
+      factory->d->localImageDir.setPath(d.path() + QDir::separator());
+      if(factory->d->localImageDir.hasImage(id_)) {
+//        myDebug() << "Reading image from old local directory" << (cdString+id_);
+        const Data::Image& img2 = factory->addCachedImageImpl(id_, LocalDir);
+        // Be sure to reset the image directory location!!
+        factory->d->localImageDir.setPath(realImageDir);
+        factory->d->localImageDir.writeImage(img2);
+        return img2;
+      }
+      factory->d->localImageDir.setPath(realImageDir);
+    }
+  }
+
   myDebug() << "***not found:" << id_;
   return Data::Image::null;
 }
@@ -494,9 +535,14 @@ void ImageFactory::clean(bool purgeTempDirectory_) {
     // just to make sure all the image locations clean themselves up
     // delete the factory (which deletes the storage objects) and
     // then recreate the factory, in case anything else needs it
+    // be sure to save local image directory if it's not a temp dir1
+    const QString localDirName = localDir();
     delete factory;
     factory = 0;
     ImageFactory::init();
+    if(QDir(localDirName).exists()) {
+      setLocalDirectory(localDirName);
+    }
   }
 }
 
@@ -603,20 +649,28 @@ void ImageFactory::emitImageMismatch() {
   emit imageLocationMismatch();
 }
 
-void ImageFactory::setLocalDirectory(const KUrl& url_) {
+QString ImageFactory::localDirectory(const KUrl& url_) {
   if(url_.isEmpty()) {
-    return;
+    return QString();
   }
   if(!url_.isLocalFile()) {
     myWarning() << "Tellico can only save images to local disk";
     myWarning() << "unable to save to " << url_;
-  } else {
-    QString dir = url_.directory(KUrl::ObeyTrailingSlash | KUrl::AppendTrailingSlash);
-    // could have already been set once
-    if(!url_.fileName().contains(QLatin1String("_files"))) {
-      dir += url_.fileName().section(QLatin1Char('.'), 0, 0) + QLatin1String("_files/");
-    }
-    factory->d->localImageDir.setPath(dir);
+    return QString();
+  }
+  QString dir = url_.directory(KUrl::ObeyTrailingSlash | KUrl::AppendTrailingSlash);
+  // could have already been set once
+  if(!url_.fileName().contains(QLatin1String("_files"))) {
+    QFileInfo fi(url_.fileName());
+    dir += fi.completeBaseName() + QLatin1String("_files/");
+  }
+  return dir;
+}
+
+void ImageFactory::setLocalDirectory(const KUrl& url_) {
+  const QString localDirName = localDirectory(url_);
+  if(!localDirName.isEmpty()) {
+    factory->d->localImageDir.setPath(localDirName);
   }
 }
 
