@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2001-2009 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2001-2014 Robby Stephenson <robby@periapsis.org>
     Copyright (C) 2011 Pedro Miguel Carvalho <kde@pmc.com.pt>
  ***************************************************************************/
 
@@ -383,6 +383,12 @@ void MainWindow::initActions() {
   IMPORT_ACTION(Import::AMC, "file_import_amc", i18n("Import Ant Movie Catalog Data..."),
                 i18n("Import an Ant Movie Catalog data file"), BarIcon(QLatin1String("amc")));
 
+  IMPORT_ACTION(Import::BoardGameGeek, "file_import_boardgamegeek", i18n("Import BoardGameGeek Collection..."),
+                i18n("Import a collection from BoardGameGeek.com"), BarIcon(QLatin1String("boardgamegeek")));
+
+  IMPORT_ACTION(Import::VinoXML, "file_import_vinoxml", i18n("Import VinoXML..."),
+                i18n("Import VinoXML data"), BarIcon(QLatin1String("vinoxml")));
+
   IMPORT_ACTION(Import::FileListing, "file_import_filelisting", i18n("Import File Listing..."),
                 i18n("Import information about files in a folder"), mimeIcon("inode/directory"));
 
@@ -599,9 +605,6 @@ void MainWindow::initActions() {
   setStandardToolBarMenuEnabled(true);
   createStandardStatusBarAction();
 
-  KStandardAction::configureToolbars(this, SLOT(slotConfigToolbar()), actionCollection());
-  KStandardAction::keyBindings(this, SLOT(slotConfigKeys()), actionCollection());
-
   m_toggleGroupWidget = new KToggleAction(i18n("Show Grou&p View"), this);
   m_toggleGroupWidget->setToolTip(i18n("Enable/disable the group view"));
   connect(m_toggleGroupWidget, SIGNAL(triggered()), SLOT(slotToggleGroupWidget()));
@@ -673,6 +676,7 @@ void MainWindow::initActions() {
   action->setShortcutConfigurable(false);
   actionCollection()->addAction(QLatin1String("quick_filter"), action);
 
+  setupGUI(Keys | ToolBar);
 #ifdef UIFILE
   myWarning() << "call!";
   createGUI(UIFILE);
@@ -1181,7 +1185,7 @@ bool MainWindow::fileSave() {
     ret = fileSaveAs();
   } else {
     // special check: if there are more than 200 images AND the "Write Images In File" config key
-    // is not set, then warn user that performance may suffer, and write result
+    // is set, then warn user that performance may suffer, and write result
     if(Config::imageLocation() == Config::ImagesInFile &&
        Config::askWriteImagesInFile() &&
        Data::Document::self()->imageCount() > MAX_IMAGES_WARN_PERFORMANCE) {
@@ -1365,32 +1369,6 @@ void MainWindow::slotEditDeselect() {
   Controller::self()->slotUpdateSelection(0, Data::EntryList());
 }
 
-void MainWindow::slotConfigToolbar() {
-  KConfigGroup config(KGlobal::config(), QLatin1String("Main Window Options"));
-  saveMainWindowSettings(config);
-#ifdef UIFILE
-  KEditToolBar dlg(actionCollection(), UIFILE);
-#else
-  KEditToolBar dlg(actionCollection());
-#endif
-  connect(&dlg, SIGNAL(newToolbarConfig()), this, SLOT(slotNewToolbarConfig()));
-  dlg.exec();
-}
-
-void MainWindow::slotNewToolbarConfig() {
-  KConfigGroup config(KGlobal::config(), QLatin1String("Main Window Options"));
-  applyMainWindowSettings(config);
-#ifdef UIFILE
-  createGUI(UIFILE);
-#else
-  createGUI();
-#endif
-}
-
-void MainWindow::slotConfigKeys() {
-  KShortcutsDialog::configure(actionCollection());
-}
-
 void MainWindow::slotToggleGroupWidget() {
   if(m_toggleGroupWidget->isChecked()) {
     m_viewTabs->show();
@@ -2167,6 +2145,7 @@ void MainWindow::importFile(Tellico::Import::Format format_, const KUrl::List& u
   if(urls_.count() > 1 &&
      format_ != Import::Bibtex &&
      format_ != Import::RIS &&
+     format_ != Import::CIW &&
      format_ != Import::PDF) {
     KUrl u = urls_.front();
     QString url = u.isLocalFile() ? u.path() : u.prettyUrl();
@@ -2196,6 +2175,16 @@ void MainWindow::importFile(Tellico::Import::Format format_, const KUrl::List& u
   }
 }
 
+void MainWindow::importText(Tellico::Import::Format format_, const QString& text_) {
+  if(text_.isEmpty()) {
+    return;
+  }
+  Data::CollPtr coll = ImportDialog::importText(format_, text_);
+  if(coll) {
+    importCollection(coll, Import::Merge);
+  }
+}
+
 bool MainWindow::importCollection(Tellico::Data::CollPtr coll_, Tellico::Import::Action action_) {
   bool failed = false;
   switch(action_) {
