@@ -50,6 +50,8 @@ public:
                                                  Tellico::Data::FieldPtr,
                                                  const QString& value1 = QString(),
                                                  const QString& value2 = QString()) {
+    Q_UNUSED(value1);
+    Q_UNUSED(value2);
     return m_ret;
   }
 
@@ -79,8 +81,6 @@ void CollectionTest::testEmpty() {
 void CollectionTest::testCollection() {
   Tellico::Data::CollPtr coll(new Tellico::Data::Collection(true)); // add default fields
 
-  // since it's the second collection created
-  QCOMPARE(coll->id(), 2);
   QCOMPARE(coll->entryCount(), 0);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Base);
   QCOMPARE(coll->fields().count(), 4);
@@ -121,6 +121,23 @@ void CollectionTest::testCollection() {
   // check created and modified values
   QCOMPARE(entry2->field(QLatin1String("cdate")), weekAgo.toString(Qt::ISODate));
   QCOMPARE(entry2->field(QLatin1String("mdate")), yesterday.toString(Qt::ISODate));
+
+  // check that mdate gets updates
+  entry2->setField(QLatin1String("title"), QLatin1String("new title"));
+  QCOMPARE(entry2->field(QLatin1String("cdate")), weekAgo.toString(Qt::ISODate));
+  QCOMPARE(entry2->field(QLatin1String("mdate")), QDate::currentDate().toString(Qt::ISODate));
+
+  // check Bug 361622 - properly handling empty rows in table
+  Tellico::Data::FieldPtr tableField(new Tellico::Data::Field(QLatin1String("table"), QLatin1String("Table"), Tellico::Data::Field::Table));
+  tableField->setFormatType(Tellico::FieldFormat::FormatName);
+  coll->addField(tableField);
+  QString tableValue = QLatin1String("Value1")
+                     + Tellico::FieldFormat::rowDelimiterString()
+                     + Tellico::FieldFormat::rowDelimiterString()
+                     + QLatin1String("Value2");
+  entry2->setField(QLatin1String("table"), tableValue);
+  QCOMPARE(entry2->formattedField(QLatin1String("table")), tableValue);
+  QCOMPARE(entry2->groupNamesByFieldName(QLatin1String("table")), QStringList() << QLatin1String("Value1") << QLatin1String("Value2"));
 }
 
 void CollectionTest::testFields() {
@@ -445,3 +462,82 @@ void CollectionTest::testDuplicate() {
   QCOMPARE(entry1->title(), QLatin1String("title1"));
   QCOMPARE(entry2->title(), QLatin1String("title2"));
 }
+
+void CollectionTest::testMergeFields() {
+  // here, we want to verify that when entries and fields from outside a collection are merged in
+  // the allowed values for the Choice fields are retained in the same order, and new values are only
+  // added if they are used
+  Tellico::Data::CollPtr coll1 = Tellico::CollectionFactory::collection(Tellico::Data::Collection::Game, true);
+  Tellico::Data::CollPtr coll2 = Tellico::CollectionFactory::collection(Tellico::Data::Collection::Game, true);
+
+  // modify the allowed values for  "platform" in collection 1
+  Tellico::Data::FieldPtr platform1 = coll1->fieldByName(QLatin1String("platform"));
+  QVERIFY(platform1);
+  QStringList newValues1 = QStringList() << QLatin1String("PSP") << QLatin1String("Xbox 360");
+  platform1->setAllowed(newValues1);
+  QVERIFY(coll1->modifyField(platform1));
+  QCOMPARE(platform1->allowed(), newValues1);
+
+  Tellico::Data::EntryPtr entry2(new Tellico::Data::Entry(coll2));
+  entry2->setField(QLatin1String("platform"), QLatin1String("PlayStation"));
+  QCOMPARE(entry2->field(QLatin1String("platform")), QLatin1String("PlayStation"));
+  coll2->addEntries(entry2);
+
+  QPair<Tellico::Data::FieldList, Tellico::Data::FieldList> p = Tellico::Data::Document::mergeFields(coll1,
+                                       Tellico::Data::FieldList() << coll2->fieldByName(QLatin1String("platform")),
+                                       Tellico::Data::EntryList() << entry2);
+
+  Tellico::Data::FieldList modifiedFields = p.first;
+  QCOMPARE(modifiedFields.count(), 1);
+  // this is the zinger right here. The list of allowed values should be the original
+  // with only the new existing value tacked on the end
+  QCOMPARE(modifiedFields.first()->allowed(), newValues1 << entry2->field(QLatin1String("platform")));
+
+  Tellico::Data::FieldList addedFields = p.second;
+  QVERIFY(addedFields.isEmpty());
+}
+
+void CollectionTest::testAppendCollection() {
+  // appending a collection adds new fields, merges existing one, and add new entries
+  // the new entries should belong to the original collection and the existing entries should 
+  // remain in the source collection
+  Tellico::Data::CollPtr coll1 = Tellico::CollectionFactory::collection(Tellico::Data::Collection::Game, true);
+  Tellico::Data::CollPtr coll2 = Tellico::CollectionFactory::collection(Tellico::Data::Collection::Game, true);
+
+  // modify the allowed values for  "platform" in collection 1
+  Tellico::Data::FieldPtr platform1 = coll1->fieldByName(QLatin1String("platform"));
+  QVERIFY(platform1);
+  QStringList newValues1 = QStringList() << QLatin1String("My Box");
+  platform1->setAllowed(newValues1);
+  QVERIFY(coll1->modifyField(platform1));
+  // add a new field
+  Tellico::Data::FieldPtr field1(new Tellico::Data::Field(QLatin1String("test"), QLatin1String("test")));
+  QVERIFY(coll1->addField(field1));
+
+  Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll1));
+  QCOMPARE(entry1->collection(), coll1);
+  coll1->addEntries(entry1);
+
+  Tellico::Data::EntryPtr entry2(new Tellico::Data::Entry(coll2));
+  QCOMPARE(entry2->collection(), coll2);
+  coll2->addEntries(entry2);
+
+  // append coll1 into coll2
+  Tellico::Data::Document::appendCollection(coll2, coll1);
+  // verify that the test field was added
+  QVERIFY(coll2->hasField(QLatin1String("test")));
+  // verified that the modified field was merged
+  Tellico::Data::FieldPtr platform2 = coll2->fieldByName(QLatin1String("platform"));
+  QVERIFY(platform2);
+  QVERIFY(platform2->allowed().contains(QLatin1String("My Box")));
+
+  // coll2 should have two entries now, both with proper parent
+  QCOMPARE(coll2->entryCount(), 2);
+  Tellico::Data::EntryList e2 = coll2->entries();
+  QCOMPARE(e2.at(0)->collection(), coll2);
+  QCOMPARE(e2.at(1)->collection(), coll2);
+
+  QCOMPARE(coll1->entryCount(), 1);
+  Tellico::Data::EntryList e1 = coll1->entries();
+  QCOMPARE(e1.at(0)->collection(), coll1);
+}
