@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2010 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2010-2011 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -28,7 +28,6 @@
 #include "themoviedbfetchertest.moc"
 #include "qtest_kde.h"
 
-#include "../fetch/fetcherjob.h"
 #include "../fetch/themoviedbfetcher.h"
 #include "../collections/videocollection.h"
 #include "../collectionfactory.h"
@@ -40,7 +39,7 @@
 
 QTEST_KDEMAIN( TheMovieDBFetcherTest, GUI )
 
-TheMovieDBFetcherTest::TheMovieDBFetcherTest() : m_loop(this) {
+TheMovieDBFetcherTest::TheMovieDBFetcherTest() : AbstractFetcherTest() {
 }
 
 void TheMovieDBFetcherTest::initTestCase() {
@@ -50,10 +49,13 @@ void TheMovieDBFetcherTest::initTestCase() {
   Tellico::ImageFactory::init();
 
   m_fieldValues.insert(QLatin1String("title"), QLatin1String("Superman Returns"));
-  m_fieldValues.insert(QLatin1String("studio"), QLatin1String("Warner Bros. Pictures"));
+  m_fieldValues.insert(QLatin1String("studio"), QLatin1String("DC Comics; Legendary Pictures; Warner Bros.; Bad Hat Harry Productions"));
   m_fieldValues.insert(QLatin1String("year"), QLatin1String("2006"));
-  m_fieldValues.insert(QLatin1String("genre"), QLatin1String("action"));
+  m_fieldValues.insert(QLatin1String("genre"), QLatin1String("adventure; fantasy; action; science fiction"));
   m_fieldValues.insert(QLatin1String("director"), QLatin1String("Bryan Singer"));
+  m_fieldValues.insert(QLatin1String("producer"), QLatin1String("Bryan Singer; jon peters; gilbert adler"));
+  m_fieldValues.insert(QLatin1String("running-time"), QLatin1String("154"));
+  m_fieldValues.insert(QLatin1String("nationality"), QLatin1String("USA"));
 }
 
 void TheMovieDBFetcherTest::testTitle() {
@@ -61,24 +63,21 @@ void TheMovieDBFetcherTest::testTitle() {
                                        QLatin1String("superman returns"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::TheMovieDBFetcher(this));
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
-  job->setMaximumResults(1);
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
 
-  job->start();
-  m_loop.exec();
+  QCOMPARE(results.size(), 1);
 
-  QCOMPARE(m_results.size(), 1);
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
+  Tellico::Data::EntryPtr entry = results.at(0);
   QHashIterator<QString, QString> i(m_fieldValues);
   while(i.hasNext()) {
     i.next();
     QString result = entry->field(i.key()).toLower();
-    QVERIFY(result.contains(i.value().toLower()));
+    //    QVERIFY(result.contains(i.value().toLower()));
+    QCOMPARE(result, i.value().toLower());
   }
-  QVERIFY(!entry->field(QLatin1String("cast")).isEmpty());
+  QStringList castList = Tellico::FieldFormat::splitTable(entry->field("cast"));
+  QVERIFY(!castList.isEmpty());
+  QCOMPARE(castList.at(0), QLatin1String("Brandon Routh::Superman / Clark Kent"));
   QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("plot")).isEmpty());
 }
@@ -96,50 +95,40 @@ void TheMovieDBFetcherTest::testTitleFr() {
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::TheMovieDBFetcher(this));
   fetcher->readConfig(cg, cg.name());
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
-  job->setMaximumResults(1);
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
 
-  job->start();
-  m_loop.exec();
+  QCOMPARE(results.size(), 1);
 
-  QCOMPARE(m_results.size(), 1);
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
-  QHashIterator<QString, QString> i(m_fieldValues);
-  while(i.hasNext()) {
-    i.next();
-    QString result = entry->field(i.key()).toLower();
-    QVERIFY(result.contains(i.value().toLower()));
+  Tellico::Data::EntryPtr entry = results.at(0);
+  QStringList fields = QStringList() << QLatin1String("title")
+                                     << QLatin1String("studio")
+                                     << QLatin1String("year")
+                                     << QLatin1String("title");
+  foreach(const QString& field, fields) {
+    QString result = entry->field(field).toLower();
+    QCOMPARE(result, m_fieldValues.value(field).toLower());
   }
-  QVERIFY(!entry->field(QLatin1String("cast")).isEmpty());
+  QStringList castList = Tellico::FieldFormat::splitTable(entry->field("cast"));
+  QVERIFY(!castList.isEmpty());
+  QCOMPARE(castList.at(0), QLatin1String("Brandon Routh::Superman / Clark Kent"));
   QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("plot")).isEmpty());
 }
 
-void TheMovieDBFetcherTest::testPerson() {
-  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Video, Tellico::Fetch::Person,
-                                       QLatin1String("bryan singer"));
+// see https://bugs.kde.org/show_bug.cgi?id=336765
+void TheMovieDBFetcherTest::testBabel() {
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Video, Tellico::Fetch::Title,
+                                       QLatin1String("babel"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::TheMovieDBFetcher(this));
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
 
-  job->start();
-  m_loop.exec();
+  QCOMPARE(results.size(), 1);
 
-  QVERIFY(m_results.size() > 0);
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
-  QVERIFY(!entry->field(QLatin1String("title")).isEmpty());
-  QVERIFY(!entry->field(QLatin1String("cast")).isEmpty());
-  QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
-  QVERIFY(!entry->field(QLatin1String("plot")).isEmpty());
+  Tellico::Data::EntryPtr entry = results.at(0);
+  QCOMPARE(entry->field("title"), QLatin1String("Babel"));
+  QCOMPARE(entry->field("year"), QLatin1String("2006"));
+  QCOMPARE(entry->field("director"), QString::fromUtf8("Alejandro González Iñárritu"));
+  QCOMPARE(entry->field("producer"), QString::fromUtf8("Alejandro González Iñárritu; Steve Golin; Jon Kilik; Ann Ruark; Corinne Golden Weber"));
 }
 
-void TheMovieDBFetcherTest::slotResult(KJob* job_) {
-  m_results = static_cast<Tellico::Fetch::FetcherJob*>(job_)->entries();
-  m_loop.quit();
-}
