@@ -30,12 +30,14 @@
 #include "../core/filehandler.h"
 #include "../images/image.h"
 #include "../images/imagefactory.h"
+#include "../images/imageinfo.h"
 #include "../tellico_kernel.h"
 #include "../tellico_utils.h"
 #include "../progressmanager.h"
 #include "../core/tellico_config.h"
 #include "../core/tellico_strings.h"
 #include "../gui/cursorsaver.h"
+#include "../newstuff/manager.h"
 #include "../tellico_debug.h"
 
 #include <kstandarddirs.h>
@@ -54,6 +56,7 @@
 #include <QLabel>
 #include <QTextStream>
 #include <QVBoxLayout>
+#include <QFileInfo>
 
 extern "C" {
 #include <libxml/HTMLparser.h>
@@ -70,6 +73,7 @@ HTMLExporter::HTMLExporter(Tellico::Data::CollPtr coll_) : Tellico::Export::Expo
     m_cancelled(false),
     m_parseDOM(true),
     m_checkCreateDir(true),
+    m_checkCommonFile(true),
     m_imageWidth(0),
     m_imageHeight(0),
     m_widget(0),
@@ -169,7 +173,7 @@ bool HTMLExporter::loadXSLTFile() {
   // do NOT do namespace processing, it messes up the XSL declaration since
   // QDom thinks there are no elements in the Tellico namespace and as a result
   // removes the namespace declaration
-  QDomDocument dom = FileHandler::readXMLFile(u, false);
+  QDomDocument dom = FileHandler::readXMLDocument(u, false);
   if(dom.isNull()) {
     myDebug() << "error loading xslt file: " << xsltfile;
     return false;
@@ -187,6 +191,12 @@ bool HTMLExporter::loadXSLTFile() {
 
   delete m_handler;
   m_handler = new XSLTHandler(dom, QFile::encodeName(xsltfile), true /*translate*/);
+  if(m_checkCommonFile && !m_handler->isValid()) {
+    NewStuff::Manager::checkCommonFile();
+    m_checkCommonFile = false;
+    delete m_handler;
+    m_handler = new XSLTHandler(dom, QFile::encodeName(xsltfile), true /*translate*/);
+  }
   if(!m_handler->isValid()) {
     delete m_handler;
     m_handler = 0;
@@ -248,6 +258,7 @@ QString HTMLExporter::text() {
   TellicoXMLExporter exporter(coll);
   exporter.setURL(url());
   exporter.setEntries(entries());
+  exporter.setFields(fields());
   exporter.setIncludeGroups(m_printGrouped);
 // yes, this should be in utf8, always
   exporter.setOptions(options() | Export::ExportUTF8 | Export::ExportImages);
@@ -313,14 +324,16 @@ void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
   // but still use "grouped by"
   QString sortString;
   if(m_printGrouped) {
-    QString s;
-    // if more than one, then it's the People pseudo-group
-    if(m_groupBy.count() > 1) {
-      s = i18n("People");
-    } else {
-      s = coll->fieldTitleByName(m_groupBy[0]);
+    if(!m_groupBy.isEmpty()) {
+      QString s;
+      // if more than one, then it's the People pseudo-group
+      if(m_groupBy.count() > 1) {
+        s = i18n("People");
+      } else {
+        s = coll->fieldTitleByName(m_groupBy[0]);
+      }
+      sortString = i18n("(grouped by %1)", s);
     }
-    sortString = i18n("(grouped by %1)", s);
 
     QString groupFields;
     for(QStringList::ConstIterator it = m_groupBy.constBegin(); it != m_groupBy.constEnd(); ++it) {
@@ -396,8 +409,10 @@ void HTMLExporter::writeImages(Tellico::Data::CollPtr coll_) {
   // and so we need to write all of them too.
   if(m_exportEntryFiles || url().isEmpty()) {
     // add all image fields to string list
-    Data::FieldList fields = coll_->imageFields();
-    foreach(Data::FieldPtr field, fields) {
+    Data::FieldList iFields = coll_->imageFields();
+    // take intersection with the fields to be exported
+    iFields = QSet<Data::FieldPtr>::fromList(iFields).intersect(fields().toSet()).toList();
+    foreach(Data::FieldPtr field, iFields) {
       imageFields.add(field->name());
     }
   }
@@ -443,7 +458,8 @@ void HTMLExporter::writeImages(Tellico::Data::CollPtr coll_) {
       // try writing
       bool success = false;
       if(useTemp) {
-        success = ImageFactory::writeCachedImage(id, ImageFactory::TempDir);
+        // for link-only images, no need to write it out
+        success = ImageFactory::imageInfo(id).linkOnly || ImageFactory::writeCachedImage(id, ImageFactory::TempDir);
       } else {
         const Data::Image& img = ImageFactory::imageById(id);
         KUrl target = imgDir;
@@ -544,7 +560,8 @@ QString HTMLExporter::fileDirName() const {
   if(!m_collectionURL.isEmpty()) {
     return QLatin1String("/");
   }
-  return url().fileName().section(QLatin1Char('.'), 0, 0) + QLatin1String("_files/");
+  QFileInfo fi(url().fileName());
+  return fi.completeBaseName() + QLatin1String("_files/");
 }
 
 // how ugly is this?
@@ -705,6 +722,7 @@ bool HTMLExporter::writeEntryFiles() {
   HTMLExporter exporter(collection());
   long opt = options() | Export::ExportForce;
   opt &= ~ExportProgress;
+  exporter.setFields(fields());
   exporter.setOptions(opt);
   exporter.setXSLTFile(m_entryXSLTFile);
   exporter.setCollectionURL(url());
